/**
 * Blended linearized wave-equation (Born)
 * modeling operator of pressure data.
 * @author: Joseph Jennings
 * @version: 2018.03.10
 */
#ifndef BBORNP_H_
#define BBORNP_H_

#include <vector>
#include "my_operator.h"
#include "axis.h"
#include "hypercube_float.h"
#include "sregf.h"

class bbornp : public my_operator {
  public:
    bbornp(){};
    bbornp(std::vector<axis> paxes, std::vector<axis> daxes, int srcz, int recz,
        hypercube_float *bvel, hypercube_float *src, float dtu, float fmax,
        std::vector<int> nb, std::vector<float> stimes, std::vector<int> xss);
    void setbwfldout(std::string wfname, int wfldj);
    void setawfldout(std::string wfname, int wfldj);
    void setnthrds(int nthd) { _nthd = nthd; };
    void setverb(int verb) { _verb = verb; };
    bool forward(bool add, my_vector *mod, my_vector *dat);
    bool adjoint(bool add, my_vector *mod, my_vector *dat);
    ~bbornp(){};
  private:
    std::vector<axis> _paxes, _daxes, _raxes;
    std::vector<float> _stimei;
    std::vector<std::vector<float>> _stimes;
    std::vector<std::vector<int>> _xss;
    std::vector<int> _nb, _xsi;
    axis _saxis;
    int _recz, _srcz, _nx, _nz, _nsx, _nt, _nrx, _wfldj;
    int _nthd = 1;
    int _verb = 0;
    hypercube_float *_bvel, *_src, *_imgs;
    float _osx = 0.0, _dsx = 1.0;
    float _dtu, _fmax;
    std::string _bwfname, _awfname;
    sregf _wfout, _awfout;
};

#endif /* BBORNP_H_ */
