/**
 * Linearized wave-equation (Born)
 * modeling operator of acoustic pressure data
 * @author: Joseph Jennings
 * @version: 2018.03.06
 */
#ifndef BORNP_H_
#define BORNP_H_

#include <omp.h>
#include <vector>
#include "my_operator.h"
#include "axis.h"
#include "hypercube_float.h"
#include "sregf.h"
#include "laplacian10thispc.h"
#include "zeropad.h"
#include "afd2dfst.h"
#include "sourcescale.h"
#include "bscat.h"
#include "scndder.h"
#include "rrec.h"

class bornp : public my_operator {
  public:
    bornp(){};
    bornp(std::vector<axis> paxes, std::vector<axis> daxes, axis saxis, int srcz, int recz,
        hypercube_float *bvel, hypercube_float *src, float dtu, float fmax);
    void setbwfldout(std::string wfname, int wfldj);
    void setawfldout(std::string wfname, int wfldj);
    void setnthrds(int nthd) { _nthd = nthd; };
    bool forward(bool add, my_vector *mod, my_vector *dat);
    bool adjoint(bool add, my_vector *mod, my_vector *dat);
    ~bornp(){};
  private:
    std::vector<axis> _paxes, _daxes, _raxes;
    axis _saxis;
    int _recz, _srcz, _nx, _nz, _nsx, _nt, _nrx, _wfldj;
    int _nthd = 1;
    hypercube_float *_bvel, *_src, *_imgs;
    float _osx, _dsx;
    float _dtu, _fmax;
    std::string _bwfname, _awfname;
    sregf _wfout, _awfout;
};

#endif /* BORNP_H_ */
