/**
 * Linearized wave-equation (Born)
 * modeling operator of acoustic particle
 * velocity data.
 * @author: Joseph Jennings
 * @version: 2017.04.27
 */
#ifndef BORNPV_H_
#define BORNPV_H_

#include <vector>
#include "my_operator.h"
#include "axis.h"
#include "hypercube_float.h"
#include "sregf.h"
#include "laplacian10thispc.h"
#include "zeropad.h"
#include "afd2dfst.h"
#include "sourcescale.h"
#include "bscat.h"
#include "scndder.h"
#include "pvrrec.h"

class bornpv : public my_operator {
  public:
    bornpv(){};
    bornpv(std::vector<axis> paxes, std::vector<axis> daxes, axis saxis, int srcz, int recz,
        hypercube_float *bvel, hypercube_float *src, float rho, float dtu, float fmax);
    void setbwfldout(std::string wfname, int wfldj);
    void setawfldout(std::string wfname, int wfldj);
    bool forward(bool add, my_vector *mod, my_vector *dat);
    bool adjoint(bool add, my_vector *mod, my_vector *dat);
    ~bornpv(){};
  private:
    std::vector<axis> _paxes, _daxes, _raxes;
    axis _saxis;
    int _recz, _srcz, _nx, _nz, _nsx, _nt, _nrx, _wfldj;
    hypercube_float *_bvel, *_src, *_imgs;
    float _osx, _dsx;
    float _rho, _dtu, _fmax;
    std::string _bwfname, _awfname;
    sregf _wfout, _awfout;
};


#endif /* BORNPV_H_ */
