/**
 * Deblends data using PEFs estimated
 * on the independently modeled data
 * @author: Joseph Jennings
 * @version: 2018.03.11
 */

#ifndef PEFDBLND_H_
#define PEFDBLND_H_

#include <vector>
#include "hypercube_float.h"
#include "lv_conv2dmask.h"
#include "lv_conv2dm.h"
#include "pefsignoi2d.h"
#include "pad2d.h"

class pefdblnd {
  public:
    pefdblnd(){};
    pefdblnd(int pefniter, int sniniter, float eps, std::vector<int> j,
        std::vector<int> nlag, std::vector<int> nb, std::vector<axis> daxes);
    void set_smmvtags(std::vector<std::string> smmvtags);
    void set_nmmvtags(std::vector<std::string> nmmvtags);
    void find_pefs(int is, std::vector<hypercube_float*> iisht, std::vector<lv_conv2dm*> &pefops);
    void apply(hypercube_float *bdata, hypercube_float *inddata, hypercube_float *dbdata);
    void set_padding(int ntp, int nrxp);
    void set_nthrds(int nthd) { _nthd = nthd; };
    void set_verb(int verb) { _verb = verb; };
    ~pefdblnd(){};
  private:
    int _pefniter, _sniniter, _nt, _nrx, _ntp, _nrxp;
    int _nthd = 1;
    int _verb = 0;
    float _dt, _drx, _ot, _orx, _eps;
    std::vector<int> _nb, _nd, _j, _nlag;
    std::vector<axis> _saxes, _paxes;
    std::vector<std::string> _smmvtags, _nmmvtags;
    std::vector<std::vector<hypercube_float*>> _odatcont;
    pad2d _pad;
};

#endif /* PEFDBLND_H_ */
