/**
 * Separates signal and noise using
 * 2D prediction-error filters
 * Am = [ I  I ][ s ]
 *      [ N  0 ][ n ]
 *      [ 0  S ]
 * where I are identity operators,
 * N is a noise PEF and S is a signal PEF.
 * @author: Joseph Jennings
 * @version: 2018.03.11
 */

#ifndef PEFSIGNOI2D_H_
#define PEFSIGNOI2D_H_

#include "combo_oper.h"
#include "my_operator.h"
#include "lv_conv2dm.h"

class pefsignoi2d : public my_operator {
  public:
    pefsignoi2d(){};
    pefsignoi2d(hypercube_float *dat, lv_conv2dm* spef, lv_conv2dm* npef);
    bool forward(bool add, my_vector *mod, my_vector *dat);
    bool adjoint(bool add, my_vector *mod, my_vector *dat);
    ~pefsignoi2d(){};

  private:
    row_op *_gam;
    diag_op *_pefs;
    col_op *_A;
};

#endif /* PEFSIGNOI2D_H_ */
