import os, sys, ConfigParser
import seppy
import numpy as np
import subprocess

# Create config parser
config = ConfigParser.RawConfigParser()
config.read(sys.argv[1])

# Modeling parameters
srcz    = config.getint( 'modeling', 'srcz'    )
recz    = config.getint( 'modeling', 'recz'    )
dtu     = config.getfloat( 'modeling' , 'dtu'  )
fmax    = config.getfloat( 'modeling' , 'fmax' )
nthread = config.getint( 'modeling', 'nthread' )
srcfile = config.get( 'modeling', 'srcfile' )
velfile = config.get( 'modeling', 'velfile' )

# Inversion parameters
datfile = config.get( 'inversion' , 'datfile' )
z1t = config.getint( 'inversion', 'z1t' )
z2t = config.getint( 'inversion', 'z2t' )
totniter  = config.getint( 'inversion', 'totniter' )
resniter  = config.getint( 'inversion', 'resniter' )
rmovsufx  = config.get( 'inversion', 'rmovsufx' )
gmovsufx  = config.get( 'inversion', 'gmovsufx' )
mmovsufx  = config.get( 'inversion', 'mmovsufx' )
ofnosufx  = config.get( 'inversion', 'ofnosufx' )
ofilesufx = config.get( 'inversion', 'ofilesufx' )

# Create the list with the iteration numbers

iters = (np.ones(totniter/resniter,dtype=np.int)*resniter).tolist()
if(totniter%resniter != 0):
  iters.append(totniter%resniter)

ctr = 1
ofiles = []
for iiter in iters:
  rmov  = rmovsufx  + '-' + str(ctr*iiter) + '.H'
  gmov  = gmovsufx  + '-' + str(ctr*iiter) + '.H'
  mmov  = mmovsufx  + '-' + str(ctr*iiter) + '.H'
  ofno  = ofnosufx  + '-' + str(ctr*iiter) + '.H'
  ofiles.append(ofilesufx + '-' + str(ctr*iiter) + '.H')
  if(ctr == 1):
    blwi = "./Bin/BLWI.x srcz=%d recz=%d dtu=%f fmax=%f \
      z1t=%d z2t=%d src=%s bvel=%s rmov=%s gmov=%s mmov=%s ofno=%s\
      niter=%d nthrds=%d < %s > %s 2>blwi%d.log"%(srcz,recz,dtu,fmax,z1t,z2t,srcfile,velfile,rmov,gmov,mmov,ofno,iiter,nthread,datfile,ofiles[ctr-1],ctr)
    print blwi
    sp = subprocess.check_call(blwi,shell=True)
  else:
    blwi = "./Bin/BLWI.x srcz=%d recz=%d dtu=%f fmax=%f \
      z1t=%d z2t=%d src=%s bvel=%s rmov=%s gmov=%s mmov=%s ofno=%s \
      niter=%d nthrds=%d m0=%s < %s > %s 2>blwi%d.log"%(srcz,recz,dtu,fmax,z1t,z2t,srcfile,velfile,rmov,gmov,mmov,ofno,iiter,nthread,ofiles[ctr-2],datfile,ofiles[ctr-1],ctr)
    print blwi
    sp = subprocess.check_call(blwi,shell=True)
  ctr += 1

