import os, sys, ConfigParser
import seppy
import numpy as np
import subprocess

# Create config parser
config = ConfigParser.RawConfigParser()
config.read(sys.argv[1])

# Modeling parameters
srcz    = config.getint( 'modeling', 'srcz'    )
recz    = config.getint( 'modeling', 'recz'    )
dtu     = config.getfloat( 'modeling' , 'dtu'  )
fmax    = config.getfloat( 'modeling' , 'fmax' )
nthread = config.getint( 'modeling', 'nthread' )
srcfile = config.get( 'modeling', 'srcfile' )
velfile = config.get( 'modeling', 'velfile' )

# Inversion parameters
datfile = config.get( 'inversion' , 'datfile' )
z1t = config.getint( 'inversion', 'z1t' )
z2t = config.getint( 'inversion', 'z2t' )
totniter  = config.getint( 'inversion', 'totniter' )
resniter  = config.getint( 'inversion', 'resniter' )
rmovsufx  = config.get( 'inversion', 'rmovsufx' )
gmovsufx  = config.get( 'inversion', 'gmovsufx' )
mmovsufx  = config.get( 'inversion', 'mmovsufx' )
ofnosufx  = config.get( 'inversion', 'ofnosufx' )
ofilesufx = config.get( 'inversion', 'ofilesufx' )

# PEF parameters
pefniter = config.getint( 'pef', 'pefniter' )
sniniter = config.getint( 'pef', 'sniniter' )
dmovsufx = config.get( 'pef', 'dmovsufx' )
ddsufx   = config.get( 'pef' , 'ddfilesufx' )
pefthrds = config.getint( 'pef', 'pefthrds' )
cdatfile = config.get( 'pef', 'cdatfile')
nlags    = config.get( 'pef', 'nlag' )
js       = config.get( 'pef' , 'j'   )
n1p      = config.getint( 'pef', 'n1pad' )
n2p      = config.getint( 'pef', 'n2pad' )

# Create the list with the iteration numbers

iters = (np.ones(totniter/resniter,dtype=np.int)*resniter).tolist()
if(totniter%resniter != 0):
  iters.append(totniter%resniter)

ctr = 1
ofiles = []; dmovs = []; dfiles = []
for iiter in iters:
  rmov  = rmovsufx  + '-' + str(ctr*iiter) + '.H'
  gmov  = gmovsufx  + '-' + str(ctr*iiter) + '.H'
  mmov  = mmovsufx  + '-' + str(ctr*iiter) + '.H'
  ofno  = ofnosufx  + '-' + str(ctr*iiter) + '.H'
  dmovs.append(dmovsufx  + '-' + str(ctr*iiter) + '.H')
  ofiles.append(ofilesufx + '-' + str(ctr*iiter) + '.H')
  dfiles.append(ddsufx + '-' + str(ctr*iiter) + '.H')
  if(ctr == 1):
    lwiwf = "./Bin/LWI_WF.x srcz=%d recz=%d dtu=%f fmax=%f \
      z1t=%d z2t=%d src=%s bvel=%s pefniter=%d sniniter=%d j=%s nlag=%s n1p=%d n2p=%d \
      pefthrds=%d cdat=%s rmov=%s gmov=%s mmov=%s ofno=%s dmov=%s \
      niter=%d modthrds=%d < %s > %s 2>lwiwf%d.log"%(srcz,recz,dtu,fmax,z1t,z2t,srcfile,velfile,pefniter,sniniter,js,nlags,n1p,n2p,pefthrds,cdatfile,rmov,gmov,mmov,ofno,dmovs[ctr-1],iiter,nthread,datfile,ofiles[ctr-1],ctr)
    print lwiwf
    sp = subprocess.check_call(lwiwf,shell=True)
  else:
    wind = "Window n4=1 f4=%d < %s > %s"%(resniter-1,dmovs[ctr-2],dfiles[ctr-2])
    print wind
    sp = subprocess.check_call(wind,shell=True)
    lwiwf = "./Bin/LWI_WF.x srcz=%d recz=%d dtu=%f fmax=%f \
      z1t=%d z2t=%d src=%s bvel=%s pefniter=%d sniniter=%d j=%s nlag=%s n1p=%d n2p=%d \
      pefthrds=%d cdat=%s rmov=%s gmov=%s mmov=%s ofno=%s dmov=%s \
      niter=%d modthrds=%d m0=%s < %s > %s 2>lwiwf%d.log"%(srcz,recz,dtu,fmax,z1t,z2t,srcfile,velfile,pefniter,sniniter,js,nlags,n1p,n2p,pefthrds,dfiles[ctr-2],rmov,gmov,mmov,ofno,dmovs[ctr-1],iiter,nthread,ofiles[ctr-2],datfile,ofiles[ctr-1],ctr)
    print lwiwf
    sp = subprocess.check_call(lwiwf,shell=True)
  ctr += 1

