/**
 * Tests the gradient taper used in
 * linearized waveform inversion
 * @author: Joseph Jennings
 * @version: 2017.05.02
 */

#include <math.h>
#include "sep_params.h"
#include "../main/grad_taper.h"
#include "../main/simpleplot.h"

int main(int argc, char **argv) {

  sep_params pars = sep_params(argc,argv);
  float z1 = pars.get_int("z1",100);
  float z2 = pars.get_int("z2",300);
  int iz = pars.get_int("ix",310);

  sregf grdin = sregf("in");

  std::vector<axis> zaxis;
  zaxis.push_back(grdin.get_axis(1));

  hypercube_float *grad = new hypercube_float(grdin.get_axes(),true);
  hypercube_float *grdt = new hypercube_float(grdin.get_axes(),true);

  grdin.read_all("in",grad);

  grad_taper tap = grad_taper(grdin.get_axis(1),z1,z2);
  tap.plot_taper(grad,iz);
  tap.forward(false,grad,grdt);

  sregf grdot = sregf(grdt->get_axes());
  grdot.write_description("out");
  grdot.write_all("out",grdt);
}
